@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler superclass
-our $VERSION = '3.20240827'; # VERSION
+our $VERSION = '3.20241011'; # VERSION
 use Mail::Milter::Authentication::Exception;
 use Mail::Milter::Authentication::Resolver;
 use Date::Format qw{ time2str };
@@ -19,6 +19,7 @@ use Proc::ProcessTable;
 use Sereal qw{encode_sereal decode_sereal};
 use Sys::Hostname;
 use Time::HiRes qw{ ualarm gettimeofday };
+use Digest::SHA qw(sha1_hex);
 
 
 our $TestResolver; # For Testing
@@ -142,6 +143,30 @@ sub rbl_check_domain {
 }
 
 
+sub rbl_check_email_address {
+    my ( $self, $email_address, $list ) = @_;
+
+    # This matches the SA HBL hash. Although the documentation says sha256-base32, they also
+    #  list all entries as sha1-hex, so we'll just use that as well
+    $email_address = lc $email_address;
+    $email_address =~ s/\+.*@/@/; # No plus addressing
+    my $entry_hash = sha1_hex($email_address);
+
+    my $resolver = $self->get_object( 'resolver' );
+    my $lookup = join( '.', $entry_hash, $list );
+    my $packet = $resolver->query( $lookup, 'A' );
+
+    if ($packet) {
+        foreach my $rr ( $packet->answer ) {
+            if (  lc $rr->type eq 'a' ) {
+                return $rr->address();
+            }
+        }
+    }
+    return 0;
+}
+
+
 sub get_microseconds {
     my ( $self ) = @_;
     my ($seconds, $microseconds) = gettimeofday;
@@ -2269,7 +2294,7 @@ Mail::Milter::Authentication::Handler - Handler superclass
 
 =head1 VERSION
 
-version 3.20240827
+version 3.20241011
 
 =head1 DESCRIPTION
 
@@ -2497,6 +2522,12 @@ Check the given domain against an rbl list.
 
 Returns true is listed.
 
+=head2 I<rbl_check_email_address( $email_address, $list )>
+
+Check the given email address against an hash rbl list.
+
+Returns true is listed.
+
 =head1 TIMEOUT METHODS
 
 =head2 I<get_microseconds()>
